"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Helpers_1 = require("../universal/Helpers");
const portOffset = 1;
class DebugUtils {
    static get isUnderPandoraDev() {
        return !!process.env.PANDORA_DEV;
    }
    static attachExecArgv(representation, targetArgv) {
        const prefixes = ['--inspect=', '--inspect-brk='];
        const targetArgvNoInspect = [];
        argLoop: for (const arg of targetArgv) {
            for (const prefix of prefixes) {
                if (arg.startsWith(prefix)) {
                    continue argLoop;
                }
            }
            targetArgvNoInspect.push(arg);
        }
        targetArgv.length = 0;
        targetArgv.push.apply(targetArgv, targetArgvNoInspect);
        // Always works on daemon process
        for (const arg of process.execArgv) {
            for (const prefix of prefixes) {
                if (arg.startsWith(prefix)) {
                    const value = arg.substring(prefix.length);
                    const { host, port: parsedPort } = Helpers_1.parseInspectPort(value);
                    const port = (parsedPort || process.debugPort) + portOffset * (representation.index + 1);
                    targetArgv.push(prefix + (host ? `${host}:${port}` : port));
                    return;
                }
            }
        }
        if (true === representation.inspector) {
            targetArgv.push('--inspect=0');
            return;
        }
        if (representation.inspector) {
            const inspector = representation.inspector;
            const host = inspector.host;
            const port = inspector.port ? inspector.port + portOffset * representation.index : null;
            if (host && port) {
                targetArgv.push(`--inspect=${host}:${port}`);
                return;
            }
            if (host) {
                targetArgv.push(`--inspect=${host}:0`);
                return;
            }
            if (port) {
                targetArgv.push(`--inspect=${port}`);
                return;
            }
        }
    }
}
exports.DebugUtils = DebugUtils;
//# sourceMappingURL=DebugUtils.js.map